/*

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: farePage
    tools: farePageTools
    orientationLock: PageOrientation.LockPortrait

    Flickable {
        anchors.top: headerRect.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: 10
        anchors.bottomMargin: 110

        contentWidth: fareGrid.width
        contentHeight: fareGrid.height
        flickableDirection: Flickable.VerticalFlick

        Grid {
            id: fareGrid
            columns: 2
            spacing: 0

            Rectangle {
                id: meterFareRect1
                width: 380
                height: 50
                color: "black"
                Text {
                    x: 10
                    color: "white"
                    anchors.verticalCenter: meterFareRect1.verticalCenter
                    font.pointSize: 18
                    text: qsTr("Meter Fare")
                    font.bold: true
                }
            }

            Rectangle {
                id: meterFareRect2
                width: 80
                height: meterFareRect1.height
                color: "black"
            }

            Text {
                id: meterFare1a
                width: meterFareRect1.width
                height: meterFare1b.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Flagdown: First km or less")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFareRect1.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: meterFare1b
                width: meterFareRect2.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$2.80\n$3.00\n$3.20")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFareRect2.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: meterFare2a
                width: meterFareRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Every 385 metres thereafter or less up to 10 km")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare1a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: meterFare2b
                width: meterFareRect2.width
                height: meterFare2a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$0.20")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare1b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: meterFare3a
                width: meterFareRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Every 330 metres thereafter or less after 10 km")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare2a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: meterFare3b
                width: meterFareRect2.width
                height: meterFare3a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$0.20")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare2b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: meterFare4a
                width: meterFareRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Every 45 seconds of waiting or less")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare3a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: meterFare4b
                width: meterFareRect2.width
                height: meterFare4a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$0.20")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: meterFare3b.bottom
                horizontalAlignment: Text.AlignRight
            }

            /* Booking Charge */

            Rectangle {
                id: bookingChargesRect1
                width: meterFareRect1.width
                height: 50
                color: "black"
                anchors.topMargin: 10
                anchors.top: meterFare4a.bottom
                Text {
                    x: 10
                    color: "white"
                    anchors.verticalCenter: bookingChargesRect1.verticalCenter
                    font.pointSize: 18
                    text: qsTr("Booking Charges")
                    font.bold: true
                }
            }

            Rectangle {
                id: bookingChargesRect2
                width: meterFareRect2.width
                height: bookingChargesRect1.height
                color: "black"
                anchors.topMargin: 10
                anchors.top: meterFare4b.bottom
            }

            Text {
                id: bookingCharges1a
                width: bookingChargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Prime Time \nMon to Fri: \n0700 - 0930/1700 - 2300")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingChargesRect1.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: bookingCharges1b
                width: bookingChargesRect2.width
                height: bookingCharges1a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$3.50")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingChargesRect2.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: bookingCharges2a
                width: bookingChargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Non-Prime Time \nAll other times (including Sat, Sun and all Public Holidays)")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingCharges1a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: bookingCharges2b
                width: bookingChargesRect2.width
                height: bookingCharges2a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$2.50")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingCharges1b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: bookingCharges3a
                width: bookingChargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Advance Booking \n(at least half an hour in advance)")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingCharges2a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: bookingCharges3b
                width: bookingChargesRect2.width
                height: bookingCharges3a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$5.20")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: bookingCharges2b.bottom
                horizontalAlignment: Text.AlignRight
            }

            /* Surcharges */

            Rectangle {
                id: surchargesRect1
                width: meterFareRect1.width
                height: 50
                color: "black"
                anchors.topMargin: 10
                anchors.top: bookingCharges3a.bottom
                Text {
                    x: 10
                    color: "white"
                    anchors.verticalCenter: surchargesRect1.verticalCenter
                    font.pointSize: 18
                    text: qsTr("Surcharges")
                    font.bold: true
                }
            }

            Rectangle {
                id: surchargesRect2
                width: meterFareRect2.width
                height: surchargesRect1.height
                color: "black"
                anchors.topMargin: 10
                anchors.top: bookingCharges3b.bottom
            }

            Text {
                id: surcharges1a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("CBD (including Marina Bay Sands) \nMon to Sat: 1700 - Midnight\nNot Applicable on Public Holidays")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surchargesRect1.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges1b
                width: surchargesRect2.width
                height: surcharges1a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$3.50")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surchargesRect2.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: surcharges2a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Peak Period \nMon to Fri: 0700 - 0930\nMon to Sat: 1700 - 2000\nNot Applicable on Public Holidays")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges1a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges2b
                width: surchargesRect2.width
                height: surcharges2a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("35% of metered fare")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges1b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: surcharges3a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Late Night\nMidnight - 0559")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges2a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges3b
                width: surchargesRect2.width
                height: surcharges3a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("50% of metered fare")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges2b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: surcharges4a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Public Holiday\nEve of P.H. 1800 - 2359 of P.H.")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges3a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges4b
                width: surchargesRect2.width
                height: surcharges4a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$1.00")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges3b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: surcharges5a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Credit Card Payment")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges4a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges5b
                width: surchargesRect2.width
                height: surcharges5a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("10% of metered fare")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges4b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: surcharges6a
                width: surchargesRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("NETS/EZ-Link Payment")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges5a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: surcharges6b
                width: surchargesRect2.width
                height: surcharges6a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$0.30")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: surcharges5b.bottom
                horizontalAlignment: Text.AlignRight
            }

            /* Location */

            Rectangle {
                id: locationRect1
                width: meterFareRect1.width
                height: 50
                color: "black"
                anchors.topMargin: 10
                anchors.top: surcharges6a.bottom
                Text {
                    x: 10
                    color: "white"
                    anchors.verticalCenter: locationRect1.verticalCenter
                    font.pointSize: 18
                    text: qsTr("Locations (Originating from)")
                    font.bold: true
                }
            }

            Rectangle {
                id: locationRect2
                width: meterFareRect2.width
                height: locationRect1.height
                color: "black"
                anchors.topMargin: 10
                anchors.top: surcharges6b.bottom
            }

            Text {
                id: location1a
                width: locationRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Singapore Changi Airport\nFri - Sun: 1700 - Midnight\nAll other times")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: locationRect1.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: location1b
                width: locationRect2.width
                height: location1a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("\n$5.00\n$3.00")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: locationRect2.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: location2a
                width: locationRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Seletar Aiport")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: location1a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: location2b
                width: locationRect2.width
                height: location2a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$3.00")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: location1b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: location3a
                width: locationRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Resort Worlds Sentosa")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: location2a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: location3b
                width: locationRect2.width
                height: location3a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$3.00")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: location2b.bottom
                horizontalAlignment: Text.AlignRight
            }

            Text {
                id: location4a
                width: locationRect1.width
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("Singapore Expo")
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.topMargin: 10
                anchors.top: location3a.bottom
                wrapMode: Text.WordWrap
            }

            Text {
                id: location4b
                width: locationRect2.width
                height: location4a.height
                anchors.margins: 10
                font.pointSize: 16
                text: qsTr("$2.00")
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.topMargin: 10
                anchors.top: location3b.bottom
                horizontalAlignment: Text.AlignRight
            }

            /* Blank */

            Rectangle {
                width: meterFareRect1.width
                height: 100
                color: "#00000000"
                anchors.topMargin: 10
                anchors.top: location4a.bottom
            }

            Rectangle {
                width: meterFareRect2.width
                height: 100
                color: "#00000000"
                anchors.topMargin: 10
                anchors.top: location4b.bottom
            }
        }
    }

    Rectangle {
        id: headerRect
        anchors.top:farePage.top; anchors.left: farePage.left; anchors.right: farePage.right
        width: farePage.width ; height: 70 ;
        color: "dark orange"
        Text {
            id: titleText
            color: "white"
            anchors.centerIn: headerRect
            font.pointSize: 24
            text: qsTr("Taxi Fare Information")
        }
    }

    ToolBarLayout {
        id: farePageTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back";
            onClicked: { pageStack.pop(); }
        }
    }
}
