/*

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

import QtQuick 1.1
import com.nokia.meego 1.0
import LaunchActions 1.0

Page {
    tools: mainPageTools
    orientationLock: PageOrientation.LockPortrait

    DBusMethodProxy {
        id: dBusMethodProxy
    }

    function openFile(file) {
        var component = Qt.createComponent(file)
        if (component.status == Component.Ready)
            pageStack.push(component);
        else
            console.log("Error loading component:", component.errorString());
    }

    Rectangle {
        id: headerRect
        anchors.top:mainPage.top; anchors.left: mainPage.left; anchors.right: mainPage.right
        width: mainPage.width ; height: 70 ;
        color: "dark orange"
        Text {
            id: titleText
            color: "white"
            anchors.centerIn: headerRect
            font.pointSize: 24
            text: qsTr("Singapore Taxi Booking")
        }
    }

    Image {
        id: mainImage
        anchors {
            topMargin: 50
            top: headerRect.bottom
            horizontalCenter: parent.horizontalCenter
        }

        sourceSize.height: 147
        sourceSize.width: 224
        source: "taxi-main.png"
    }

    Label {
        id: lblBooking
        anchors {
            topMargin: 50
            top: mainImage.bottom
            horizontalCenter: parent.horizontalCenter
        }

        text: qsTr("Select a company to book from: ")
    }

    ButtonColumn {
        anchors {
            horizontalCenter: parent.horizontalCenter
            top: lblBooking.bottom
            topMargin: 10
        }

        Button {
            text: qsTr("Common Booking")
            onClicked: { dBusMethodProxy.call("63425222") }
        }

        Button {
            text: qsTr("Comfort/CityCab")
            onClicked: { dBusMethodProxy.call("65521111") }
        }

        Button {
            text: qsTr("TransCab")
            onClicked: { dBusMethodProxy.call("65553333") }
        }

        Button {
            text: qsTr("SMRT Taxis")
            onClicked: { dBusMethodProxy.call("65558888") }
        }

        Button {
            text: qsTr("Premier Silvercab")
            onClicked: { dBusMethodProxy.call("63636888") }
        }

        Button {
            text: qsTr("SMART Cab")
            onClicked: { dBusMethodProxy.call("64857777") }
        }

        Button {
            text: qsTr("Prime")
            onClicked: { dBusMethodProxy.call("67780808") }
        }
    }

    QueryDialog {
        id: query

        icon: "taxi-main.png"
        titleText: "SGTaxi 1.0.0"
        message: "SGTaxi is an app which allows for taxi booking in Singapore as well as display fare information.\nAn open-source project by \nSteve Teo - @KellTainer and distributed under the GPL3 license. \n\nThe project can be found at https://github.com/KellTainer/SG-Taxi"
        acceptButtonText: "Ok"
    }

    ToolBarLayout {
        id: mainPageTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-contact";
            onClicked: { query.open(); }
        }
        ToolIcon {
            platformIconId: "toolbar-grid"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: { openFile("FarePage.qml"); }
        }
    }
}
